[Bf-extensions-cvs] [4e1cda98] master: Spelling fixes in comments and descriptions, patch by luzpaz

Brecht Van Lommel noreply at git.blender.org
Wed Jul 31 13:34:48 CEST 2019


Commit: 4e1cda9885a6ef508396a8f60c292350af8f3f3d
Author: Brecht Van Lommel
Date:   Wed Jul 31 13:27:19 2019 +0200
Branches: master
https://developer.blender.org/rBA4e1cda9885a6ef508396a8f60c292350af8f3f3d

Spelling fixes in comments and descriptions, patch by luzpaz

Differential Revision: https://developer.blender.org/D5240

===================================================================

M	add_curve_sapling/utils.py
M	add_mesh_BoltFactory/createMesh.py
M	animation_add_corrective_shape_key.py
M	archimesh/achm_roof_maker.py
M	archipack/archipack_gl.py
M	archipack/archipack_manipulator.py
M	blenderkit/__init__.py
M	blenderkit/append_link.py
M	blenderkit/download.py
M	blenderkit/paths.py
M	blenderkit/search.py
M	blenderkit/ui.py
M	blenderkit/upload.py
M	blenderkit/utils.py
M	io_anim_bvh/export_bvh.py
M	io_coat3D/tex.py
M	io_export_paper_model.py
M	io_mesh_atomic/utility_panel.py
M	io_scene_fbx/export_fbx_bin.py
M	io_scene_gltf2/blender/com/gltf2_blender_material_helpers.py
M	io_scene_gltf2/blender/exp/gltf2_blender_gather_nodes.py
M	io_scene_gltf2/blender/imp/gltf2_blender_animation_node.py
M	io_scene_gltf2/blender/imp/gltf2_blender_primitive.py
M	io_scene_gltf2/blender/imp/gltf2_blender_scene.py
M	io_scene_gltf2/io/exp/gltf2_io_draco_compression_extension.py
M	io_scene_x3d/import_x3d.py
M	mesh_auto_mirror.py
M	mesh_bsurfaces.py
M	mesh_inset/triquad.py
M	mesh_looptools.py
M	mesh_snap_utilities_line/op_line.py
M	mesh_tiny_cad/VTX.py
M	mesh_tissue/colors_groups_exchanger.py
M	mesh_tissue/tessellate_numpy.py
M	mesh_tissue/utils.py
M	object_carver/carver_draw.py
M	object_color_rules.py
M	object_fracture_cell/fracture_cell_setup.py
M	rigify/__init__.py
M	rigify/legacy/utils.py
M	rigify/rig_ui_template.py
M	rigify/utils/widgets.py
M	space_view3d_align_tools.py
M	space_view3d_copy_attributes.py
M	space_view3d_math_vis/__init__.py

===================================================================

diff --git a/add_curve_sapling/utils.py b/add_curve_sapling/utils.py
index 4ec2cd83..3dbe53af 100644
--- a/add_curve_sapling/utils.py
+++ b/add_curve_sapling/utils.py
@@ -1358,7 +1358,7 @@ def perform_pruning(baseSize, baseSplits, childP, cu, currentMax, currentMin, cu
                         stemsegL, lengthV[n], taperCrown, boneStep, rotate, rotateV
                         )
 
-        # If pruning is enabled then we must to the check to see if the end of the spline is within the evelope
+        # If pruning is enabled then we must check to see if the end of the spline is within the envelope
         if prune:
             # Check each endpoint to see if it is inside
             for s in splineList:
diff --git a/add_mesh_BoltFactory/createMesh.py b/add_mesh_BoltFactory/createMesh.py
index 71f22bf7..6c18eeef 100644
--- a/add_mesh_BoltFactory/createMesh.py
+++ b/add_mesh_BoltFactory/createMesh.py
@@ -233,20 +233,20 @@ def Mirror_Verts_Faces(VERTS, FACES, AXIS, FLIP_POINT=0):
 
 # Returns a list of faces that
 # make up an array of 4 point polygon.
-def Build_Face_List_Quads(OFFSET, COLUM, ROW, FLIP=0):
+def Build_Face_List_Quads(OFFSET, COLUMN, ROW, FLIP=0):
     Ret = []
     RowStart = 0
     for j in range(ROW):
-        for i in range(COLUM):
+        for i in range(COLUMN):
             Res1 = RowStart + i
-            Res2 = RowStart + i + (COLUM + 1)
-            Res3 = RowStart + i + (COLUM + 1) + 1
+            Res2 = RowStart + i + (COLUMN + 1)
+            Res3 = RowStart + i + (COLUMN + 1) + 1
             Res4 = RowStart + i + 1
             if FLIP:
                 Ret.append([OFFSET + Res1, OFFSET + Res2, OFFSET + Res3, OFFSET + Res4])
             else:
                 Ret.append([OFFSET + Res4, OFFSET + Res3, OFFSET + Res2, OFFSET + Res1])
-        RowStart += COLUM + 1
+        RowStart += COLUMN + 1
     return Ret
 
 
diff --git a/animation_add_corrective_shape_key.py b/animation_add_corrective_shape_key.py
index dcfd6811..320acc83 100644
--- a/animation_add_corrective_shape_key.py
+++ b/animation_add_corrective_shape_key.py
@@ -50,12 +50,12 @@ Limitations and new delta option for 2.8
   it will be set to zero.
   
 - new "delta" option usage, when you hope to make new shape-key with keep currently visible other shape keys value.
- it can generate new shape key, with value as 1.00. then deform target shape as soruce shape  with keep other shape key values relative.
-  
-- If overwrite shape key,<select active shape key of target as non "base shape"> 
- current shape key value is ignored and turn as 1.00. 
- 
- then if active shape key was driven (bone rotation etc), you may get un-expected result. When transfer, I recommend, keep set active-shape key as base . so transfered shape key do not "overwrite". but generate new shape key. 
+ it can generate new shape key, with value as 1.00. then deform target shape as source shape with keep other shape key values relative.
+
+- If overwrite shape key,<select active shape key of target as non "base shape">
+ current shape key value is ignored and turn as 1.00.
+
+ then if active shape key was driven (bone rotation etc), you may get un-expected result. When transfer, I recommend, keep set active-shape key as base. so transferred shape key do not "overwrite". but generate new shape key.
  if active-shape key have no driver, you can overwrite it (but as 1.00 value )
 """
 
@@ -254,7 +254,7 @@ class add_corrective_pose_shape(bpy.types.Operator):
 class add_corrective_pose_shape_delta (bpy.types.Operator):
     """Adds first object as shape to second object for the current pose """ \
     """while maintaining modifiers and currently used other shape keys""" \
-    """with keep other shape key value, generate new shape key which deform to soruce shape """
+    """with keep other shape key value, generate new shape key which deform to source shape """
 
     bl_idname = "object.add_corrective_pose_shape_delta"
     bl_label = "Add object as corrective pose shape delta"
diff --git a/archimesh/achm_roof_maker.py b/archimesh/achm_roof_maker.py
index 1b446779..c125eb84 100644
--- a/archimesh/achm_roof_maker.py
+++ b/archimesh/achm_roof_maker.py
@@ -172,7 +172,7 @@ def create_roof_mesh(self):
     bpy.context.view_layer.objects.active = myroof
     myroof.select_set(True)
 
-    # Thicknes
+    # Thickness
     if self.roof_thick > 0.0:
         set_modifier_solidify(myroof, self.roof_thick)
     # Subsurf
diff --git a/archipack/archipack_gl.py b/archipack/archipack_gl.py
index 17211787..f3ef034a 100644
--- a/archipack/archipack_gl.py
+++ b/archipack/archipack_gl.py
@@ -584,7 +584,7 @@ class GlLine(GlBaseLine):
     def sized_normal(self, t, size):
         """
             GlLine perpendicular on plane defined by z_axis and of given size
-            positionned at t in current line
+            positioned at t in current line
             lie on the right side
             p1
             |--x
diff --git a/archipack/archipack_manipulator.py b/archipack/archipack_manipulator.py
index 2b9010d6..60a05738 100644
--- a/archipack/archipack_manipulator.py
+++ b/archipack/archipack_manipulator.py
@@ -1073,7 +1073,7 @@ class SizeLocationManipulator(SizeManipulator):
 
         Also take care of moving linked objects too
         Changing size is not necessary as link does
-        allredy handle this and childs panels are
+        already handle this and childs panels are
         updated by base object.
     """
     def __init__(self, context, o, datablock, manipulator, handle_size, snap_callback=None):
@@ -1185,7 +1185,7 @@ class SnapSizeLocationManipulator(SizeLocationManipulator):
 
         Also take care of moving linked objects too
         Changing size is not necessary as link does
-        allredy handle this and childs panels are
+        already handle this and childs panels are
         updated by base object.
 
 
diff --git a/blenderkit/__init__.py b/blenderkit/__init__.py
index 4fbf3783..6a2a68b3 100644
--- a/blenderkit/__init__.py
+++ b/blenderkit/__init__.py
@@ -274,7 +274,7 @@ class BlenderKitUIProps(PropertyGroup):
     thumb_size: IntProperty(name="Thumbnail Size", default=thumb_size_def, min=-1, max=256)
 
     margin: IntProperty(name="Margin", default=margin_def, min=-1, max=256)
-    highlight_margin: IntProperty(name="Higlight Margin", default=int(margin_def / 2), min=-10, max=256)
+    highlight_margin: IntProperty(name="Highlight Margin", default=int(margin_def / 2), min=-10, max=256)
 
     bar_height: IntProperty(name="Bar Height", default=thumb_size_def + 2 * margin_def, min=-1, max=2048)
     bar_x_offset: IntProperty(name="Bar X Offset", default=20, min=0, max=5000)
diff --git a/blenderkit/append_link.py b/blenderkit/append_link.py
index 8b399986..efbd1492 100644
--- a/blenderkit/append_link.py
+++ b/blenderkit/append_link.py
@@ -45,7 +45,7 @@ def append_material(file_name, matname=None, link=False, fake_user=True):
     '''append a material type asset'''
     # first, we have to check if there is a material with same name
     # in previous step there's check if the imported material
-    # is allready in the scene, so we know same name != same material
+    # is already in the scene, so we know same name != same material
 
     mats_before = bpy.data.materials.keys()
 
diff --git a/blenderkit/download.py b/blenderkit/download.py
index b0830a4e..ac43bc88 100644
--- a/blenderkit/download.py
+++ b/blenderkit/download.py
@@ -312,7 +312,7 @@ def append_asset(asset_data, **kwargs):  # downloaders=[], location=None,
             sprops.append_link = 'APPEND'
             sprops.import_as = 'INDIVIDUAL'
 
         # set consistency for objects allready in scene, otherwise this literally breaks blender :)
         ain = asset_in_scene(asset_data)
         if ain is not False:
             if ain == 'LINKED':
@@ -382,7 +382,7 @@ def append_asset(asset_data, **kwargs):  # downloaders=[], location=None,
 
     elif asset_data['asset_type'] == 'brush':
 
         # TODO if allready in scene, should avoid reappending.
         inscene = False
         for b in bpy.data.brushes:
 
@@ -539,7 +539,7 @@ class Downloader(threading.Thread):
         get_download_url(asset_data, scene_id, api_key, tcom=tcom)
         if tcom.error:
             return
         # only now we can check if the file allready exists. This should have 2 levels, for materials and for brushes
         # different than for the non free content. delete is here when called after failed append tries.
         if check_existing(asset_data) and not tcom.passargs.get('delete'):
             # this sends the thread for processing, where another check should occur, since the file might be corrupted.
@@ -622,7 +622,7 @@ def download(asset_data, **kwargs):
 
 
 def check_downloading(asset_data, **kwargs):
-    ''' check if an asset is allready downloading, if yes, just make a progress bar with downloader object.'''
+    ''' check if an asset is already downloading, if yes, just make a progress bar with downloader object.'''
     global download_threads
 
     downloading = False
@@ -646,7 +646,7 @@ def check_existing(asset_data):
 
     file_names = paths.get_download_filenames(asset_data)
 
-    utils.p('check if file allready exists')
+    utils.p('check if file already exists')
     if len(file_names) == 2:
         # TODO this should check also for failed or running downloads.
         # If download is running, assign just the running thread. if download isn't running but the file is wrong size,
@@ -663,11 +663,11 @@ def check_existing(asset_data):
 
 
 def try_finished_append(asset_data, **kwargs):  # location=None, material_target=None):
-    ''' try to append asset, if not successfull delete source files.
+    ''' try to append asset, if not successfully delete source files.
      This means probably wrong download, so download should restart'''
     file_names = paths.get_download_filenames(asset_data)
     done = False
-    utils.p(

@@ Diff output truncated at 10240 characters. @@
@@ -312,7 +312,7 @@ def append_asset(asset_data, **kwargs):  # downloaders=[], location=None,
             sprops.import_as = 'INDIVIDUAL'
 
-        # set consistency for objects allready in scene, otherwise this literally breaks blender :)
+        # set consistency for objects already in scene, otherwise this literally breaks blender :)
         ain = asset_in_scene(asset_data)
         if ain is not False:
@@ -382,7 +382,7 @@ def append_asset(asset_data, **kwargs):  # downloaders=[], location=None,
     elif asset_data['asset_type'] == 'brush':
 
-        # TODO if allready in scene, should avoid reappending.
+        # TODO if already in scene, should avoid reappending.
         inscene = False
         for b in bpy.data.brushes:
@@ -539,7 +539,7 @@ class Downloader(threading.Thread):
         if tcom.error:
             return
-        # only now we can check if the file allready exists. This should have 2 levels, for materials and for brushes
+        # only now we can check if the file already exists. This should have 2 levels, for materials and for brushes
         # different than for the non free content. delete is here when called after failed append tries.
         if check_existing(asset_data) and not tcom.passargs.get('delete'):



More information about the Bf-extensions-cvs mailing list